==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/EmailContent.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EmailContent
 */
@JsonPropertyOrder({ EmailContent.JSON_PROPERTY_BODY, EmailContent.JSON_PROPERTY_SUBJECT })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class EmailContent implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BODY = "body";
    private String body;

    public static final String JSON_PROPERTY_SUBJECT = "subject";
    private String subject;

    public EmailContent() {
    }

    public EmailContent body(String body) {

        this.body = body;
        return this;
    }

    /**
     * The HTML body of the email. May contain [variable
     * references](https://velocity.apache.org/engine/1.7/user-guide.html#references). &lt;x-lifecycle
     * class&#x3D;\&quot;ea\&quot;&gt;&lt;/x-lifecycle&gt; Not required if Custom languages for Okta Email Templates is
     * enabled. A &#x60;null&#x60; body is replaced with a default value from one of the following in priority order: 1.
     * An existing default email customization, if one exists 2. Okta-provided translated content for the specified
     * language, if one exists 3. Okta-provided translated content for the brand locale, if it&#39;s set 4.
     * Okta-provided content in English
     *
     * @return body
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "The HTML body of the email. May contain [variable references](https://velocity.apache.org/engine/1.7/user-guide.html#references).   <x-lifecycle class=\"ea\"></x-lifecycle> Not required if Custom languages for Okta Email Templates is enabled. A `null` body is replaced with a default value from one of the following in priority order:  1. An existing default email customization, if one exists 2. Okta-provided translated content for the specified language, if one exists 3. Okta-provided translated content for the brand locale, if it's set  4. Okta-provided content in English ")
    @JsonProperty(JSON_PROPERTY_BODY)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getBody() {
        return body;
    }

    @JsonProperty(JSON_PROPERTY_BODY)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setBody(String body) {
        this.body = body;
    }

    public EmailContent subject(String subject) {

        this.subject = subject;
        return this;
    }

    /**
     * The email subject. May contain [variable
     * references](https://velocity.apache.org/engine/1.7/user-guide.html#references). &lt;x-lifecycle
     * class&#x3D;\&quot;ea\&quot;&gt;&lt;/x-lifecycle&gt; Not required if Custom languages for Okta Email Templates is
     * enabled. A &#x60;null&#x60; subject is replaced with a default value from one of the following in priority order:
     * 1. An existing default email customization, if one exists 2. Okta-provided translated content for the specified
     * language, if one exists 3. Okta-provided translated content for the brand locale, if it&#39;s set 4.
     * Okta-provided content in English
     *
     * @return subject
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "The email subject. May contain [variable references](https://velocity.apache.org/engine/1.7/user-guide.html#references).  <x-lifecycle class=\"ea\"></x-lifecycle> Not required if Custom languages for Okta Email Templates is enabled. A `null` subject is replaced with a default value from one of the following in priority order:  1. An existing default email customization, if one exists 2. Okta-provided translated content for the specified language, if one exists 3. Okta-provided translated content for the brand locale, if it's set 4. Okta-provided content in English ")
    @JsonProperty(JSON_PROPERTY_SUBJECT)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getSubject() {
        return subject;
    }

    @JsonProperty(JSON_PROPERTY_SUBJECT)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setSubject(String subject) {
        this.subject = subject;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EmailContent emailContent = (EmailContent) o;
        return Objects.equals(this.body, emailContent.body) && Objects.equals(this.subject, emailContent.subject);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(body, subject);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EmailContent {\n");
        sb.append("    body: ").append(toIndentedString(body)).append("\n");
        sb.append("    subject: ").append(toIndentedString(subject)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/EmailContent.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EmailContent
 */
@JsonPropertyOrder({ EmailContent.JSON_PROPERTY_BODY, EmailContent.JSON_PROPERTY_SUBJECT })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class EmailContent implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BODY = "body";
    private String body;

    public static final String JSON_PROPERTY_SUBJECT = "subject";
    private String subject;

    public EmailContent() {
    }

    public EmailContent body(String body) {

        this.body = body;
        return this;
    }

    /**
     * The HTML body of the email. May contain [variable
     * references](https://velocity.apache.org/engine/1.7/user-guide.html#references). &lt;x-lifecycle
     * class&#x3D;\&quot;ea\&quot;&gt;&lt;/x-lifecycle&gt; Not required if Custom languages for Okta Email Templates is
     * enabled. A &#x60;null&#x60; body is replaced with a default value from one of the following in priority order: 1.
     * An existing default email customization, if one exists 2. Okta-provided translated content for the specified
     * language, if one exists 3. Okta-provided translated content for the brand locale, if it&#39;s set 4.
     * Okta-provided content in English
     *
     * @return body
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "The HTML body of the email. May contain [variable references](https://velocity.apache.org/engine/1.7/user-guide.html#references).   <x-lifecycle class=\"ea\"></x-lifecycle> Not required if Custom languages for Okta Email Templates is enabled. A `null` body is replaced with a default value from one of the following in priority order:  1. An existing default email customization, if one exists 2. Okta-provided translated content for the specified language, if one exists 3. Okta-provided translated content for the brand locale, if it's set  4. Okta-provided content in English ")
    @JsonProperty(JSON_PROPERTY_BODY)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getBody() {
        return body;
    }

    @JsonProperty(JSON_PROPERTY_BODY)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setBody(String body) {
        this.body = body;
    }

    public EmailContent subject(String subject) {

        this.subject = subject;
        return this;
    }

    /**
     * The email subject. May contain [variable
     * references](https://velocity.apache.org/engine/1.7/user-guide.html#references). &lt;x-lifecycle
     * class&#x3D;\&quot;ea\&quot;&gt;&lt;/x-lifecycle&gt; Not required if Custom languages for Okta Email Templates is
     * enabled. A &#x60;null&#x60; subject is replaced with a default value from one of the following in priority order:
     * 1. An existing default email customization, if one exists 2. Okta-provided translated content for the specified
     * language, if one exists 3. Okta-provided translated content for the brand locale, if it&#39;s set 4.
     * Okta-provided content in English
     *
     * @return subject
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "The email subject. May contain [variable references](https://velocity.apache.org/engine/1.7/user-guide.html#references).  <x-lifecycle class=\"ea\"></x-lifecycle> Not required if Custom languages for Okta Email Templates is enabled. A `null` subject is replaced with a default value from one of the following in priority order:  1. An existing default email customization, if one exists 2. Okta-provided translated content for the specified language, if one exists 3. Okta-provided translated content for the brand locale, if it's set 4. Okta-provided content in English ")
    @JsonProperty(JSON_PROPERTY_SUBJECT)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getSubject() {
        return subject;
    }

    @JsonProperty(JSON_PROPERTY_SUBJECT)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setSubject(String subject) {
        this.subject = subject;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EmailContent emailContent = (EmailContent) o;
        return Objects.equals(this.body, emailContent.body) && Objects.equals(this.subject, emailContent.subject);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(body, subject);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EmailContent {\n");
        sb.append("    body: ").append(toIndentedString(body)).append("\n");
        sb.append("    subject: ").append(toIndentedString(subject)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
